/******************************************************************************
* File Name: main.c
*
* Version 1.40
*
* Description: 
*  This code example demonstrates the basic usage of the EZI2C Slave Component. 
*  EZI2C receives packets with commands that control the RGB LED color. 
*  EZI2C also provides a a counter which tracks how many commands have been
*  written to the slave device.
*
* Related Document: 
*  CE195362_PSoC4_EZI2C_Slave_SCB.pdf
*
* Hardware Dependency: 
*  See CE195362_PSoC4_EZI2C_Slave_SCB.pdf
*
*******************************************************************************
* Copyright (2018), Cypress Semiconductor Corporation. All rights reserved.
*******************************************************************************
* This software, including source code, documentation and related materials
* (“Software”), is owned by Cypress Semiconductor Corporation or one of its
* subsidiaries (“Cypress”) and is protected by and subject to worldwide patent
* protection (United States and foreign), United States copyright laws and
* international treaty provisions. Therefore, you may use this Software only
* as provided in the license agreement accompanying the software package from
* which you obtained this Software (“EULA”).
*
* If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
* non-transferable license to copy, modify, and compile the Software source
* code solely for use in connection with Cypress’s integrated circuit products.
* Any reproduction, modification, translation, compilation, or representation
* of this Software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND, 
* EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress 
* reserves the right to make changes to the Software without notice. Cypress 
* does not assume any liability arising out of the application or use of the 
* Software or any product or circuit described in the Software. Cypress does 
* not authorize its products for use in any products where a malfunction or 
* failure of the Cypress product may reasonably be expected to result in 
* significant property damage, injury or death (“High Risk Product”). By 
* including Cypress’s product in a High Risk Product, the manufacturer of such 
* system or application assumes all risk of such use and in doing so agrees to 
* indemnify Cypress against all liability. 
*******************************************************************************/

#include <project.h>

/* LED constants for turning the RGB LED on and off */
#define LED_ON              (0xFFu)
#define LED_OFF             (0x00u)
    
/* Buffer and packet size */
#define BUFFER_SIZE         (0x04)
#define PACKET_SIZE         (0x03)

/* Indices of the RGB color control bytes, The first 3-bytes are writable to the
   LED while the 4th byte is a counter */
#define RED_INDEX           (0x00u)
#define GREEN_INDEX         (0x01u)
#define BLUE_INDEX          (0x02u)
#define COUNT_INDEX         (0x03u) 

/* Define the count index to be read only */
#define READ_ONLY_OFFSET    (3u)
    
    
/* The EZI2C slave buffer for Write and Read */
uint8 ezI2cBuffer[BUFFER_SIZE]; 

/*******************************************************************************
* Function Name: main
********************************************************************************
* 
* Summary:
*  This function:
*   1. Turns on the green LED.
*   2. Sets up the EZI2C Slave buffer.
*   3. Starts the EZI2C Slave Component.
*   4. Enables the global interrupts.
*   5. Waits for the command from the I2C master to control the RGB LED.
*
*******************************************************************************/
int main()
{
    //uint8 status = STS_CMD_FAIL;
    
    /* Initialize the PWM components */
    PWM_Green_Start();
    PWM_Red_Start();
    PWM_Blue_Start();
    
    /* Turn on the green LED */
    PWM_Green_WriteCompare(LED_ON);
    PWM_Blue_WriteCompare(LED_OFF);
    PWM_Red_WriteCompare(LED_OFF);
    
    /* Set up a buffer and start the EZI2C slave (SCB mode) */
    EZI2C_EzI2CSetBuffer1(BUFFER_SIZE, READ_ONLY_OFFSET, ezI2cBuffer);
    EZI2C_Start();

    /* Enable global interrupts */
    CyGlobalIntEnable;

    for(;;)
    {
        /* The Write is complete: parse the packet */
        if (0u != (EZI2C_EzI2CGetActivity() & EZI2C_EZI2C_STATUS_WRITE1))
        {
            /* Increment the number of writes */
            ezI2cBuffer[COUNT_INDEX]++;
            
            /* Update the PWM Compare values to control color and intensity */
            PWM_Green_WriteCompare(ezI2cBuffer[GREEN_INDEX]);
            PWM_Blue_WriteCompare(ezI2cBuffer[BLUE_INDEX]);
            PWM_Red_WriteCompare(ezI2cBuffer[RED_INDEX]);
                            
        }
    }
}


/* [] END OF FILE */
